Additional methods to manage apps in the app catalog
Module that contains methods and functions to manage apps from the app catalog.
Generated methods
DshApiClient methods that are generated from the openapi specification.
delete_appcatalog_app_configuration(appcatalogappid)delete_application_configuration(appid)get_appcatalog_app_configuration(appcatalogappid) -> AppCatalogAppConfigurationget_appcatalog_app_status(appcatalogappid) -> AllocationStatusget_appcatalogapp_actual(appcatalogappid) -> AppCatalogAppget_appcatalogapp_actual_map() -> HashMap<id, AppCatalogApp>get_appcatalogapp_configuration(appcatalogappid) -> AppCatalogAppget_appcatalogapp_configuration_map() -> HashMap<id, AppCatalogApp>put_appcatalog_app_configuration(appcatalogappid, body)
Derived methods
DshApiClient methods that add extra capabilities but do not directly call the
DSH resource management API. These derived methods depend on the API methods for this.
app_configuration(app_id) -> (app, configuration)app_configurations() -> [(app id, app, configuration)]app_ids() -> [app_id]apps_dependant_on_application(application_id) -> [app]apps_dependant_on_bucket(bucket_id) -> [app]apps_dependant_on_certificate(certificate_id) -> [app]apps_dependant_on_secret(secret_name) -> [app]apps_dependant_on_topic(topic_id) -> [app]apps_dependant_on_vhost(vhost_id) -> [app]apps_dependant_on_volume(volume_id) -> [app]
Functions
- apps_
that_ use_ application - Find apps that use an application
- apps_
that_ use_ certificate - Find apps that use a certificate
- apps_
that_ use_ secret - Find apps that use a given secret
- apps_
that_ use_ topic - Find apps that use a given topic
- apps_
that_ use_ vhost - Find apps that use a given vhost
- apps_
that_ use_ volume - Find apps that use a given volume