Function topic_resources_from_app
Source pub fn topic_resources_from_app(
app: &AppCatalogApp,
) -> Option<Vec<(&String, &Topic)>>
Get topic resources from AppCatalogApp
Parameters
app - app to get the topic resources from
Returns
Either None when the app does not have any topic resources,
or a Some that contains tuples describing the topic resources:
- resource id
- reference to the
Topic