Module application

Additional methods and functions to manage applications

Module that contains methods and functions to manage applications.

  • Derived methods - DshApiClient methods that add extra capabilities but depend on the API methods.
  • Functions - Functions that add extra capabilities but do not depend directly on the API.

Derived methods

DshApiClient methods that add extra capabilities but do not directly call the DSH resource management API. These derived methods depend on the API methods for this.

Structs

ApplicationDiff
Structure that contains the differences between two Applications

Functions

differences_between_applications
Compare Applications
find_applications_that_use_secret
Find secret injections in Applications
find_applications_that_use_secrets
Get applications that use any of a list of given secret injections
find_applications_that_use_topic
Find topic injections in Applications
find_applications_that_use_volume
Get applications that use a given volume injection
get_secret_from_application
Find secret injections in Application
parse_image_string
Parses an image string
secrets_from_application
Get all secret injections in Application
vhosts_from_application
Get all vhost injections from Application
vhosts_from_applications
Get all vhost injections from Applications