Function secrets_from_application

pub fn secrets_from_application(
    application: &Application,
) -> Vec<(String, Vec<Injection>)>
Get all secret injections in Application

Parameters

  • application - reference to the Application

Returns

  • Vec(<String, Vec<Injection>)> - list of tuples that describe the secret injections. Each tuple consist of the secret id and the environment variables that the secret is injected into.