Module bucket

Module bucket 

Additional methods to manage buckets

Module that contains methods and functions to manage buckets.

Generated methods

DshApiClient methods that are generated from the openapi specification.

Derived methods

DshApiClient methods that add extra capabilities but do not directly call the DSH resource management API. These derived methods depend on the API methods for this.

Enums

BucketInjection
Describes an injection of a resource in an application

Constants

OBJECT_STORE_ACCESS_KEY_ID
Secret name for object store access key id
OBJECT_STORE_SECRET_ACCESS_KEY
Secret name for object store secret access key

Functions

bucket_injections_from_application
Get application environment variables referencing bucket
bucket_injections_from_applications
Get applications environment variables referencing bucket
bucket_resources_from_app
Get bucket resources from AppCatalogApp
buckets_from_application
Get application environment variables referencing buckets
buckets_from_applications
Get applications environment variables referencing buckets