buckets_from_application

Function buckets_from_application 

pub fn buckets_from_application(
    application: &Application,
) -> Vec<EnvVarInjection<'_>>
Get application environment variables referencing buckets

Get all environment variables from an Application that reference a bucket. When the application does not reference any buckets, an empty list will be returned.

Parameters

  • application - reference to the Application

Returns

Vec<EnvInjection> - list of tuples containing:

  • bucket id
  • list of environment variables referencing the bucket

The list is sorted by bucket id.