dsh_api::dsh_api_client_factory

Struct DshApiClientFactory

pub struct DshApiClientFactory { /* private fields */ }
Factory for DSH API client

Implementations

Source

impl DshApiClientFactory

pub fn new() -> DshApiClientFactory

Create default factory for DSH API client

This function will create a new DshApiClientFactory from the default environment variables.

Examples
use dsh_api::dsh_api_client_factory::DshApiClientFactory;

let client_factory = DshApiClientFactory::new();
if let Ok(client) = client_factory.client().await {
  println!("rest api version is {}", client.api_version());
}
Panics

This function will panic if it cannot create a new DshApiClientFactory from the default environment variables. If you want to capture such a failure, use the create() function.

pub fn create(tenant: DshApiTenant, secret: String) -> Result<Self, DshApiError>

Create factory for DSH API client

This function will create a new DshApiClientFactory from the provided parameters.

Parameters
  • tenant - Tenant struct, containing the platform, tenant name and the tenant’s group and user id.
  • secret - The secret used to retrieve the DSH API tokens.
Returns
  • Ok<DshApiClientFactory> - the created client factory
  • Err<String> - when the client factory could not be created
Examples
use dsh_api::dsh_api_client_factory::DshApiClientFactory;
use dsh_api::dsh_api_tenant::DshApiTenant;

let secret = "...".to_string();
let tenant = DshApiTenant::from_tenant("greenbox".to_string())?;
let client_factory = DshApiClientFactory::create(tenant, secret)?;
let client = client_factory.client().await?;
println!("rest api version is {}", client.api_version());
pub fn try_default() -> Result<Self, DshApiError>

Create default factory for DSH API client

This function will create a new DshApiClientFactory from the default platform and tenant.

Returns
  • Ok<DshApiClientFactory> - the created client factory
  • Err<String> - when the client factory could not be created
Examples
use dsh_api::dsh_api_client_factory::DshApiClientFactory;

let client_factory = DshApiClientFactory::try_default()?;
let client = client_factory.client().await?;
println!("rest api version is {}", client.api_version());
pub fn platform(&self) -> &DshPlatform

Returns the factories platform
pub fn tenant(&self) -> &DshApiTenant

Returns the factories tenant
pub fn tenant_name(&self) -> &str

Returns the name of the factories tenant
pub fn guid(&self) -> u16

Returns the group and user id of the factories tenant
pub async fn client(&self) -> Result<DshApiClient<'_>, DshApiError>

Create an DSH API client

This function will create a new DshApiClient.

Returns
  • Ok<DshApiClient> - the created client
  • Err<String> - error message when the client could not be created
Examples
use dsh_api::dsh_api_client_factory::DshApiClientFactory;

let client_factory = DshApiClientFactory::new();
match client_factory.client().await {
  Ok(client) => println!("rest api version is {}", client.api_version()),
  Err(error) => println!("could not create client ({})", error),
}