DshApiTenant

Struct DshApiTenant 

pub struct DshApiTenant { /* private fields */ }

Implementations

Source

impl DshApiTenant

pub fn new<T>(name: T, platform: DshPlatform) -> Self
where T: Into<String>,

Create new DSH API tenant.

Parameters
  • name - Client tenant’s name.
  • platform - Target platform for the API.
Examples
let name = "my-tenant";
let platform = DshPlatform::try_from("nplz")?;
let dsh_api_tenant = DshApiTenant::new(name, platform);
assert_eq!(
  dsh_api_tenant.platform().internal_domain("my-tenant"),
  "my-tenant.marathon.mesos".to_string()
);
pub fn from_tenant<T>(tenant_name: T) -> DshApiResult<Self>
where T: Into<String>,

Create new DSH API tenant from tenant’s name.

This factory function will attempt to create a DshapiTenant instance from the provided tenant’s name. The platform will be read from the environment variable DSH_API_PLATFORM. The function will return an Error<String> if the environment variables are not set or contains illegal values.

Parameters
  • tenant_name - Tenant’s name.
Returns
  • Ok(tenant) - Tenant struct.
  • Err(error) - Configuration error.
Examples
let tenant_name = "my-tenant";
let dsh_api_tenant = DshApiTenant::from_tenant(tenant_name)?;
println!("target platform: {}", dsh_api_tenant.platform());
pub fn from_tenant_and_platform<T>( tenant_name: T, platform: DshPlatform, ) -> DshApiResult<Self>
where T: Into<String>,

Create new DSH API tenant from tenant’s name and platform.

This factory function will attempt to create a DshapiTenant instance from the provided tenant’s name. The function will return an Error<String> if the environment variable is not set.

Parameters
  • tenant_name - Tenant’s name.
  • platform - Target platform for the API.
Returns
  • Ok(tenant) - Tenant struct.
  • Err(error) - Configuration error.
Examples
let tenant_name = String::from("my-tenant");
let platform = DshPlatform::try_from("nplz")?;
let dsh_api_tenant = DshApiTenant::from_tenant_and_platform(tenant_name, platform)?;
println!("{}@{}", dsh_api_tenant.name(), dsh_api_tenant.platform());
pub fn from_platform(platform: DshPlatform) -> DshApiResult<Self>

Create new DSH API tenant from platform.

This factory function will attempt to create a DshapiTenant instance from the provided platform. The tenant’s name will be read from the environment variable. The function will return an Error<String> if the environment variables are not set.

Parameters
  • platform - Target platform for the API
Returns
  • Ok(tenant) - Tenant struct.
  • Err(error) - Configuration error.
Examples
let platform = DshPlatform::try_from("nplz")?;
let dsh_api_tenant = DshApiTenant::from_platform(platform)?;
println!("{}@{}", dsh_api_tenant.name(), dsh_api_tenant.platform());
pub fn try_default() -> DshApiResult<Self>

Returns the default tenant

This method will read the tenant name and platform form the respective environment variables and will create aDshApiTenant if possible. It will return an Error<String> when one or more of these the environment variables is not set or contains an undefined value.

Returns
  • Ok<tenant> - When the environment variables are provided and contain valid values.
  • Error<String> - when one or more of the environment variables is not set or contains an undefined value
Examples
let default_tenant = DshApiTenant::try_default()?;
println!("{}@{}", default_tenant.name(), default_tenant.platform());
pub fn platform(&self) -> &DshPlatform

Returns the client’s platform

pub fn name(&self) -> &String

Returns the client’s tenant name