pub enum Dependant<T> {
App {
app: DependantApp,
},
Application {
application: DependantApplication<T>,
},
Certificate {
certificate: DependantCertificate,
},
Proxy {
proxy: DependantProxy,
},
Trifonius {
trifonius: DependantTrifonius<T>,
},
}Expand description
Describes a app or application dependency.
There are a number of methods that return whether a certain resource (e.g. a secret, a volume or an environment variable) is used by a dependant app or application. This enum represents one usage of the resource by an app or application.
Variants
App
Identifies an app dependent on the resource
Fields

app: DependantAppApplication
Identifies an application dependent on the resource
Fields

application: DependantApplication<T>Certificate
Identifies a certificate dependent on the resource
Fields

certificate: DependantCertificateProxy
Identifies a proxy dependent on the resource
Fields

proxy: DependantProxyTrifonius
Identifies a Trifonius dependent on the resource
Fields

trifonius: DependantTrifonius<T>Implementations
Sourceimpl<T> Dependant<T>
impl<T> Dependant<T>
pub fn app(app_id: String, resources: Vec<String>) -> Self
pub fn application( application_id: String, instances: u64, injections: Vec<T>, ) -> Self
pub fn certificate( certificate_id: String, secret_kind: CertificateSecretKind, ) -> Self
pub fn proxy(proxy_id: String, instances: u64) -> Self
pub fn service(service_id: &str, instances: u64, injections: Vec<T>) -> Self
pub fn trifonius( trifonius_id: String, instances: u64, injections: Vec<T>, ) -> Self
pub fn id(&self) -> &str