pub enum DshApiError {
BadRequest {
message: Option<String>,
},
Configuration {
message: String,
},
Conversion {
message: String,
},
NotAuthorized {
message: Option<String>,
},
NotFound {
message: Option<String>,
},
Parameter {
message: String,
},
Unexpected {
message: String,
cause: Option<String>,
},
Unprocessable {
message: Option<String>,
},
}Expand description
Describes an API error.
Variants
BadRequest
DSH Api server indicated that the request was not correct (BAD_REQUEST).
Configuration
Misconfiguration error, e.g. a missing environment variable.
Conversion
Conversion error, e.g. an unknown attribute.
NotAuthorized
Not authorized for the requested operation or resource.
NotFound
Requested resource does not exist.
Parameter
Wrong parameters provided.
Unexpected
Unexpected error occurred.
Unprocessable
DSH Api server indicated that the request could not be processed (UNPROCESSABLE_ENTITY).