Additional methods to manage proxies
Module that contains methods and functions to manage proxies.
Generated methods
DshApiClient methods that are generated from the openapi specification.
delete_kafkaproxy_configuration(id)get_kafkaproxy_actual(id) -> KafkaProxyget_kafkaproxy_configuration(id) -> KafkaProxyget_kafkaproxy_ids() -> Vec<String>get_kafkaproxy_status(id) -> AllocationStatusput_kafkaproxy_configuration(id, proxy)
Derived methods
DshApiClient methods that add extra capabilities but do not directly call the
DSH resource management API. These derived methods depend on the API methods for this.
Functions
- proxies_
that_ use_ certificate - Find proxies that use a certificate
- proxies_
that_ use_ secret - Find proxies that use a secret