Module query_processor

Enums, traits and structs used by the various find methods

Structs

DummyQueryProcessor
Dummy query processor implementation
ExactMatchQueryProcessor
Query processor implementation for exact matches
RegexQueryProcessor
Query processor implementation based on regular expressions

Enums

Part
Represents a part of a matched query.

Traits

QueryProcessor
Defines the methods in the query processor

Functions

part_to_ansi_formatted_string
Generate string with ansi formatting from a Part
parts_to_ansi_formatted_string
Generate string with ansi formatting from a slice of Parts