pub enum Part {
Matching(String),
NonMatching(String),
}Expand description
Represents a part of a matched query.
Variants
Matching(String)
Represents a part of a string that did match the query.
NonMatching(String)
Represents a part of a string that did not match the query.
Implementations