pub struct DummyQueryProcessor {}Expand description
Dummy query processor implementation
This dummy query processor always returns the literal haystack as a
single non-matching Part.
This can be useful when you want to apply a function that expects a query processor,
without actually applying the query.
Implementations
Sourceimpl DummyQueryProcessor
impl DummyQueryProcessor
pub fn create() -> DshApiResult<Self>