pub struct DependantApplication<T> {
pub application_id: String,
pub instances: u64,
pub injections: Vec<T>,
}Expand description
Describes an application dependency.
There are a number of methods that return whether a certain resource (e.g. a secret, a volume or an environment variable) is used by a dependant application. This struct represents one usage of the resource by an application.
Fields
application_id: StringIdentifies the dependant application.
instances: u64Number of instances of the dependant application.
injections: Vec<T>Injections that the dependencies originate from.
Implementations