pub struct DependantCertificate {
pub certificate_id: String,
pub secret_kind: CertificateSecretKind,
}Expand description
Describes a certificate dependency
There are a number of methods that return whether a certain resource (e.g. a secret) is used by a certificate. This struct represents one usage of the resource by a certificate.
Fields
certificate_id: StringIdentifies the dependant certificate
secret_kind: CertificateSecretKindKind of secret for the Certificate dependency.
Implementations
Sourceimpl DependantCertificate
impl DependantCertificate
pub fn new(certificate_id: String, secret_kind: CertificateSecretKind) -> Self