AllocationStatus

Struct AllocationStatus 

pub struct AllocationStatus {
    pub derived_from: Option<String>,
    pub notifications: Vec<Notification>,
    pub provisioned: bool,
}
AllocationStatus

JSON schema
{
 "type": "object",
 "required": [
   "notifications",
   "provisioned"
 ],
 "properties": {
   "derivedFrom": {
     "description": "pointer to the parent allocation or limit that caused this allocation to be implicitly created\n",
     "type": "string"
   },
   "notifications": {
     "type": "array",
     "items": {
       "$ref": "#/components/schemas/Notification"
     }
   },
   "provisioned": {
     "description": "indicates whether configuration and actual state match",
     "type": "boolean"
   }
 },
 "example": {
   "derivedFrom": "derivedFrom",
   "notifications": [
     {
       "args": {
         "key": "args"
       },
       "message": "message",
       "remove": true
     },
     {
       "args": {
         "key": "args"
       },
       "message": "message",
       "remove": true
     }
   ],
   "provisioned": true
 }
}

Fields

derived_from: Option<String>

pointer to the parent allocation or limit that caused this allocation to be implicitly created

notifications: Vec<Notification>provisioned: bool

indicates whether configuration and actual state match

Implementations

Source

impl AllocationStatus

Source

impl AllocationStatus

pub fn new<T>(derived_from: T, provisioned: bool) -> Self
where T: Into<String>,

Create a new AllocationStatus

Create a new AllocationStatus from the provided parameters. The other fields of the AllocationStatus instance will be set to their default values.

Parameters
  • derived_from - name of the service that the resource for this allocation status was derived from
  • provisioned - whether the service was provisioned
Returns

The created AllocationStatus.

Example
let allocation_status = AllocationStatus::new("my-service", true);
assert_eq!(allocation_status.derived_from.unwrap(), "my-service".to_string());
assert_eq!(allocation_status.provisioned, true);
assert!(allocation_status.notifications.is_empty());