pub struct ApplicationSecret {
pub injections: Vec<HashMap<String, String>>,
pub name: String,
}Expand description
a secret to be injected as an environment variable in the application
JSON schema
{
"description": "a secret to be injected as an environment variable in the application",
"examples": [
{
"injections": [
{
"key": "injections"
},
{
"key": "injections"
}
],
"name": "name"
}
],
"type": "object",
"required": [
"injections",
"name"
],
"properties": {
"injections": {
"description": "a list of environment variable names. The secret's value may be injected multiple times as different environment variables, so multiple environment variable names for the same secret can be provided",
"type": "array",
"items": {
"type": "object",
"additionalProperties": {
"type": "string"
}
}
},
"name": {
"description": "the secret's name",
"type": "string"
}
}
}Fields
injections: Vec<HashMap<String, String>>a list of environment variable names. The secret’s value may be injected multiple times as different environment variables, so multiple environment variable names for the same secret can be provided
name: Stringthe secret’s name