pub struct FlinkCluster {
pub job_manager: Option<FlinkJobManager>,
pub task_manager: Option<FlinkTaskManager>,
pub version: String,
pub zone: String,
}Expand description
FlinkCluster
JSON schema
{
"examples": [
{
"jobManager": {
"cpus": 0.3,
"mem": 1024
},
"taskManager": {
"cpus": 0.3,
"instances": 2,
"mem": 3072
},
"version": "version",
"zone": "zone"
}
],
"type": "object",
"required": [
"version",
"zone"
],
"properties": {
"jobManager": {
"$ref": "#/components/schemas/FlinkJobManager"
},
"taskManager": {
"$ref": "#/components/schemas/FlinkTaskManager"
},
"version": {
"description": "Flink version",
"type": "string"
},
"zone": {
"description": "Network zone this cluster needs to run in. /components/schemas/Zone contains a list of available network zones in this platform.",
"type": "string"
}
}
}Fields
job_manager: Option<FlinkJobManager>task_manager: Option<FlinkTaskManager>version: StringFlink version
zone: StringNetwork zone this cluster needs to run in. /components/schemas/Zone contains a list of available network zones in this platform.