pub struct InternalManagedStream {
pub kafka_properties: HashMap<String, String>,
pub kind: InternalManagedStreamKind,
pub partitions: i64,
pub replication_factor: i64,
}Expand description
An internal stream. A stream that can be shared between different tenants, but is not accessible over the MQTT protocol adapter.
JSON schema
{
"description": "An internal stream. A stream that can be shared between different tenants, but is not accessible over the MQTT protocol adapter.\n",
"examples": [
{
"$ref": "#/components/examples/managedInternalStream"
}
],
"type": "object",
"allOf": [
{
"$ref": "#/components/schemas/Topic"
},
{
"$ref": "#/components/schemas/InternalManagedStream_allOf"
}
]
}Fields
kafka_properties: HashMap<String, String>kind: InternalManagedStreamKindFor internal streams, the value of kind must be internal.
partitions: i64replication_factor: i64Trait Implementations
Sourceimpl Clone for InternalManagedStream
impl Clone for InternalManagedStream
Sourcefn clone(&self) -> InternalManagedStream
fn clone(&self) -> InternalManagedStream
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InternalManagedStream
impl Debug for InternalManagedStream
Sourceimpl<'de> Deserialize<'de> for InternalManagedStream
impl<'de> Deserialize<'de> for InternalManagedStream
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for InternalManagedStream
impl Display for InternalManagedStream
Sourceimpl From<&InternalManagedStream> for InternalManagedStream
impl From<&InternalManagedStream> for InternalManagedStream
Sourcefn from(value: &InternalManagedStream) -> Self
fn from(value: &InternalManagedStream) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for InternalManagedStream
impl PartialEq for InternalManagedStream
Sourceimpl Serialize for InternalManagedStream
impl Serialize for InternalManagedStream
impl StructuralPartialEq for InternalManagedStream