pub struct KafkaProxyValidation {
pub common_name: Option<String>,
pub country: Option<String>,
pub locality: Option<String>,
pub organization: Option<String>,
pub organizational_unit: Option<String>,
pub province: Option<String>,
pub subject_type: KafkaProxyValidationSubjectType,
}Expand description
client certificate validations, only non empty values taken in account, no values means no validation
JSON schema
{
"description": "client certificate validations, only non empty values taken in account, no values means no validation",
"type": "object",
"required": [
"subjectType"
],
"properties": {
"commonName": {
"type": "string"
},
"country": {
"type": "string"
},
"locality": {
"type": "string"
},
"organization": {
"type": "string"
},
"organizationalUnit": {
"type": "string"
},
"province": {
"type": "string"
},
"subjectType": {
"description": "EXACT for exact match, PATTERN for pattern match",
"type": "string",
"enum": [
"EXACT",
"PATTERN"
]
}
}
}Fields
common_name: Option<String>country: Option<String>locality: Option<String>organization: Option<String>organizational_unit: Option<String>province: Option<String>subject_type: KafkaProxyValidationSubjectTypeEXACT for exact match, PATTERN for pattern match