pub struct LimitValueCertificateCountAllOf {
pub value: i64,
}Expand description
LimitValueCertificateCountAllOf
JSON schema
{
"type": "object",
"required": [
"value"
],
"properties": {
"value": {
"description": "The number of certificates available for the managed tenant",
"type": "integer",
"maximum": 40.0,
"minimum": 1.0
}
}
}Fields
value: i64The number of certificates available for the managed tenant