pub struct LimitValueKafkaAclGroupCount {
pub name: LimitValueKafkaAclGroupCountName,
pub value: i64,
}Expand description
LimitValueKafkaAclGroupCount
JSON schema
{
"allOf": [
{
"$ref": "#/components/schemas/BaseLimitValue"
},
{
"$ref": "#/components/schemas/LimitValueKafkaAclGroupCount_allOf"
}
]
}Fields
name: LimitValueKafkaAclGroupCountNamevalue: i64The number of Kafka ACL groups available for the managed tenant
Implementations
Sourceimpl LimitValueKafkaAclGroupCount
impl LimitValueKafkaAclGroupCount
Sourcepub fn new(kafka_acl_group_count: i64) -> Self
pub fn new(kafka_acl_group_count: i64) -> Self
Create a new LimitValueKafkaAclGroupCount
Create a new LimitValueKafkaAclGroupCount from the provided parameter.
The name field will be set to LimitValueKafkaAclGroupCountName::KafkaAclGroupCount.
Parameters
kafka_acl_group_count- maximum number of kafka acl groups
Returns
The created LimitValueKafkaAclGroupCount.
Example
let limit_value = LimitValueKafkaAclGroupCount::new(40);
assert_eq!(limit_value.name, LimitValueKafkaAclGroupCountName::KafkaAclGroupCount);
assert_eq!(limit_value.value, 40);Trait Implementations
Sourceimpl Clone for LimitValueKafkaAclGroupCount
impl Clone for LimitValueKafkaAclGroupCount
Sourcefn clone(&self) -> LimitValueKafkaAclGroupCount
fn clone(&self) -> LimitValueKafkaAclGroupCount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LimitValueKafkaAclGroupCount
impl Debug for LimitValueKafkaAclGroupCount
Sourceimpl<'de> Deserialize<'de> for LimitValueKafkaAclGroupCount
impl<'de> Deserialize<'de> for LimitValueKafkaAclGroupCount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<LimitValueKafkaAclGroupCount> for LimitValue
impl From<LimitValueKafkaAclGroupCount> for LimitValue
Sourcefn from(value: LimitValueKafkaAclGroupCount) -> Self
fn from(value: LimitValueKafkaAclGroupCount) -> Self
Converts to this type from the input type.
Sourceimpl From<LimitValueKafkaAclGroupCount> for LimitValueKafkaAclGroupCount
impl From<LimitValueKafkaAclGroupCount> for LimitValueKafkaAclGroupCount
Sourcefn from(value: LimitValueKafkaAclGroupCount) -> Self
fn from(value: LimitValueKafkaAclGroupCount) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for LimitValueKafkaAclGroupCount
impl PartialEq for LimitValueKafkaAclGroupCount
Sourcefn eq(&self, other: &LimitValueKafkaAclGroupCount) -> bool
fn eq(&self, other: &LimitValueKafkaAclGroupCount) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<LimitValueKafkaAclGroupCount> for LimitValueKafkaAclGroupCount
impl TryFrom<LimitValueKafkaAclGroupCount> for LimitValueKafkaAclGroupCount
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: LimitValueKafkaAclGroupCount,
) -> Result<Self, ConversionError>
fn try_from( value: LimitValueKafkaAclGroupCount, ) -> Result<Self, ConversionError>
Performs the conversion.
impl StructuralPartialEq for LimitValueKafkaAclGroupCount