pub struct LimitValueMemAllOf {
pub value: i64,
}Expand description
LimitValueMemAllOf
JSON schema
{
"type": "object",
"required": [
"value"
],
"properties": {
"value": {
"description": "The amount of memory available for the managed tenant (MiB)",
"type": "integer",
"maximum": 131072.0,
"minimum": 1.0
}
}
}Fields
value: i64The amount of memory available for the managed tenant (MiB)