pub struct LimitValueSecretCountAllOf {
pub value: NonZeroU64,
}Expand description
LimitValueSecretCountAllOf
JSON schema
{
"type": "object",
"required": [
"value"
],
"properties": {
"value": {
"description": "The number of secrets available for the managed tenant",
"type": "integer",
"maximum": 40.0,
"minimum": 1.0
}
}
}Fields
value: NonZeroU64The number of secrets available for the managed tenant
Implementations
Sourceimpl LimitValueSecretCountAllOf
impl LimitValueSecretCountAllOf
pub fn builder() -> LimitValueSecretCountAllOf