pub struct LimitValueTopicCount {
pub name: LimitValueTopicCountName,
pub value: NonZeroU64,
}Expand description
LimitValueTopicCount
JSON schema
{
"allOf": [
{
"$ref": "#/components/schemas/BaseLimitValue"
},
{
"$ref": "#/components/schemas/LimitValueTopicCount_allOf"
}
]
}Fields
name: LimitValueTopicCountNamevalue: NonZeroU64The number of topics available for the managed tenant
Implementations
Sourceimpl LimitValueTopicCount
impl LimitValueTopicCount
pub fn builder() -> LimitValueTopicCount
Sourceimpl LimitValueTopicCount
impl LimitValueTopicCount
Sourcepub fn new(topic_count: u64) -> Self
pub fn new(topic_count: u64) -> Self
Create a new LimitValueTopicCount
Create a new LimitValueTopicCount from the provided parameter.
The name field will be set to LimitValueTopicCountName::TopicCount.
Parameters
topic_count- maximum number of topics
Returns
The created LimitValueTopicCount.
Example
let limit_value = LimitValueTopicCount::new(20);
assert_eq!(limit_value.name, LimitValueTopicCountName::TopicCount);
assert_eq!(limit_value.value.get(), 20);Trait Implementations
Sourceimpl Clone for LimitValueTopicCount
impl Clone for LimitValueTopicCount
Sourcefn clone(&self) -> LimitValueTopicCount
fn clone(&self) -> LimitValueTopicCount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LimitValueTopicCount
impl Debug for LimitValueTopicCount
Sourceimpl Default for LimitValueTopicCount
impl Default for LimitValueTopicCount
Sourceimpl<'de> Deserialize<'de> for LimitValueTopicCount
impl<'de> Deserialize<'de> for LimitValueTopicCount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for LimitValueTopicCount
impl Display for LimitValueTopicCount
Sourceimpl From<LimitValueTopicCount> for LimitValue
impl From<LimitValueTopicCount> for LimitValue
Sourcefn from(value: LimitValueTopicCount) -> Self
fn from(value: LimitValueTopicCount) -> Self
Converts to this type from the input type.
Sourceimpl From<LimitValueTopicCount> for LimitValueTopicCount
impl From<LimitValueTopicCount> for LimitValueTopicCount
Sourcefn from(value: LimitValueTopicCount) -> Self
fn from(value: LimitValueTopicCount) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for LimitValueTopicCount
impl PartialEq for LimitValueTopicCount
Sourceimpl Serialize for LimitValueTopicCount
impl Serialize for LimitValueTopicCount
Sourceimpl TryFrom<LimitValueTopicCount> for LimitValueTopicCount
impl TryFrom<LimitValueTopicCount> for LimitValueTopicCount
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.
Sourcefn try_from(value: LimitValueTopicCount) -> Result<Self, ConversionError>
fn try_from(value: LimitValueTopicCount) -> Result<Self, ConversionError>
Performs the conversion.
impl StructuralPartialEq for LimitValueTopicCount