pub struct PublicManagedStream {
pub contract: PublicManagedStreamContract,
pub kafka_properties: HashMap<String, String>,
pub partitions: i64,
pub replication_factor: i64,
}Expand description
A public stream. A stream that can be shared between different tenants, and is accessible over the MQTT protocol adapter.
JSON schema
{
"description": "A public stream. A stream that can be shared between different tenants, and is accessible over the MQTT protocol adapter.\n",
"type": "object",
"allOf": [
{
"$ref": "#/components/schemas/ManagedStream"
},
{
"$ref": "#/components/schemas/PublicManagedStream_allOf"
}
]
}Fields
contract: PublicManagedStreamContractkafka_properties: HashMap<String, String>Additional Kafka properties to be set on the topic. The properties are key-value pairs. The key is the property name and the value is the property value. The following properties are allowed:
cleanup.policy:delete|compactcompression.type:uncompressed|zstd|lz4|snappy|gzip|producerdelete.retention.ms: min 0max.message.bytes: min1024, max1048576(1024x1024)message.timestamp.type:CreateTime|LogAppendTimeretention.bytesmin 0retention.msmin3600000(1 hour), max:3,1536E+10(365 days)segment.bytes: min52428800(1024x1024x50)
partitions: i64replication_factor: i64Trait Implementations
Sourceimpl Clone for PublicManagedStream
impl Clone for PublicManagedStream
Sourcefn clone(&self) -> PublicManagedStream
fn clone(&self) -> PublicManagedStream
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PublicManagedStream
impl Debug for PublicManagedStream
Sourceimpl<'de> Deserialize<'de> for PublicManagedStream
impl<'de> Deserialize<'de> for PublicManagedStream
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for PublicManagedStream
impl Display for PublicManagedStream
Sourceimpl From<&PublicManagedStream> for PublicManagedStream
impl From<&PublicManagedStream> for PublicManagedStream
Sourcefn from(value: &PublicManagedStream) -> Self
fn from(value: &PublicManagedStream) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for PublicManagedStream
impl PartialEq for PublicManagedStream
Sourceimpl Serialize for PublicManagedStream
impl Serialize for PublicManagedStream
impl StructuralPartialEq for PublicManagedStream