pub struct PublicManagedStreamContract {
pub can_be_retained: bool,
pub partitioner: PublicManagedStreamContractPartitioner,
}Expand description
The stream contract for a public stream.
JSON schema
{
"description": "The stream contract for a public stream.",
"type": "object",
"required": [
"canBeRetained",
"partitioner"
],
"properties": {
"canBeRetained": {
"description": "Whether MQTT records can have the \"retained\" flag.",
"type": "boolean"
},
"partitioner": {
"description": "The partitioner used to partition messages across different kafka partitions.",
"oneOf": [
{
"$ref": "#/components/schemas/PublicManagedStreamTopicLevelPartitioner"
},
{
"$ref": "#/components/schemas/PublicManagedStreamKafkaDefaultPartitioner"
}
],
"discriminator": {
"mapping": {
"kafkaDefault": "#/components/schemas/PublicManagedStreamKafkaDefaultPartitioner",
"topicLevel": "#/components/schemas/PublicManagedStreamTopicLevelPartitioner"
},
"propertyName": "kind"
}
}
}
}Fields
can_be_retained: boolWhether MQTT records can have the “retained” flag.
partitioner: PublicManagedStreamContractPartitionerThe partitioner used to partition messages across different kafka partitions.
Implementations