Module vhost

Additional method to manage vhosts

Module that contains methods and functions to manage vhosts.

  • Derived methods - DshApiClient methods that add extra capabilities but depend on the API methods.

Derived methods