pub enum VhostInjection {
EnvVar {
env_var_name: String,
},
Variable {
variable_name: String,
},
Vhost {
exposed_port: String,
zone: Option<String>,
},
}Expand description
Describes an injection of a resource in an application
Variants
EnvVar
Environment variable injection, where the value is the name of the environment variable.
Variable
Variable function, where the values are the name of the function and the parameter.
Vhost
Vhost injection, where the values are the exposed port and the zone