Module volume

Additional methods to manage volumes

Module that contains methods to manage volumes.

  • Derived methods - DshApiClient methods that add extra capabilities but depend on the API methods.

Derived methods

DshApiClient methods that add extra capabilities but do not directly call the DSH resource management API. These derived methods depend on the API methods for this.