Module app

Additional methods and functions to manage apps in the app catalog

Module that contains methods and functions to manage apps from the app catalog.

  • Derived methods - DshApiClient methods that add extra capabilities but depend on the API methods.
  • Functions - Functions that add extra capabilities but do not depend directly on the API.

Derived methods

DshApiClient methods that add extra capabilities but do not directly call the DSH resource management API. These derived methods depend on the API methods for this.

Functions

application_resources_from_app
Get application resources from AppCatalogApp
bucket_resources_from_app
Get bucket resources from AppCatalogApp
certificate_resources_from_app
Get certificate resources from AppCatalogApp
find_apps_that_use_secret
Find apps that use a given secret
find_apps_that_use_secrets
Find apps that use any of a list of given secret
find_apps_that_use_topic
Find apps that use a given topic
find_apps_that_use_volume
Find apps that use a given volume
secret_resources_from_app
Get secret resources from AppCatalogApp
topic_resources_from_app
Get topic resources from AppCatalogApp
vhost_resources_from_app
Get vhost resources from AppCatalogApp
vhosts_from_app
Get all vhost injections from AppCatalogApp
volume_resources_from_app
Get volume resources from AppCatalogApp