Manage apps in the App Catalog
Module that contains functions to manage pre-packaged, easily configured apps that you can select from the App Catalog.
- API methods - DshApiClient methods that directly call the API.
- Derived methods - DshApiClient methods that add extra capabilities but depend on the API methods.
- Functions - Functions that add extra capabilities but do not depend directly on the API.
API methods
DshApiClient methods that directly call the DSH resource management API.
get_app_configuration(app_id) -> appget_app_configurations() -> map<app_id, app>list_app_configurations() -> [(app_id, app)]list_app_ids() -> [app_id]
Derived methods
DshApiClient methods that add extra capabilities but do not directly call the
DSH resource management API. These derived methods depend on the API methods for this.
Actual configuration methods
Functions
- application_
resources_ from_ app - Get application resources from
AppCatalogApp - bucket_
resources_ from_ app - Get bucket resources from
AppCatalogApp - certificate_
resources_ from_ app - Get certificate resources from
AppCatalogApp - find_
apps_ that_ use_ secret - Find apps that use a given secret
- find_
apps_ that_ use_ secrets - Find apps that use any of a list of given secret
- find_
apps_ that_ use_ topic - Find apps that use a given topic
- find_
apps_ that_ use_ volume - Find apps that use a given volume
- secret_
resources_ from_ app - Get secret resources from
AppCatalogApp - topic_
resources_ from_ app - Get topic resources from
AppCatalogApp - vhost_
resources_ from_ app - Get vhost resources from
AppCatalogApp - vhosts_
from_ app - Get all vhost injections from
AppCatalogApp - volume_
resources_ from_ app - Get volume resources from
AppCatalogApp