Additional methods and functions to manage applications
Module that contains methods and functions to manage applications.
- Derived methods - DshApiClient methods that add extra capabilities but depend on the API methods.
- Functions - Functions that add extra capabilities but do not depend directly on the API.
Derived methods
DshApiClient methods that add extra capabilities but do not directly call the
DSH resource management API. These derived methods depend on the API methods for this.
find_applications(predicate) -> [(id, application)]find_applications_that_use_env_value(query) -> [(id, application, envs)]find_applications_with_secret_injections(secret) -> [(id, application, injections)]list_application_allocation_statuses() -> [(id, allocation_status)]list_application_ids() -> [id]list_applications() -> [(id, application)]list_applications_with_secret_injections() -> [(id, application, injections)]
Structs
- Application
Diff - Structure that contains the differences between two
Applications
Functions
- differences_
between_ applications - Compare Applications
- find_
applications_ that_ use_ secret - Find secret injections in
Applications - find_
applications_ that_ use_ secrets - Get applications that use any of a list of given secret injections
- find_
applications_ that_ use_ topic - Find topic injections in
Applications - find_
applications_ that_ use_ volume - Get applications that use a given volume injection
- get_
secret_ from_ application - Find secret injections in
Application - parse_
image_ string - Parses an image string
- secrets_
from_ application - Get all secret injections in
Application - vhosts_
from_ application - Get all vhost injections from
Application - vhosts_
from_ applications - Get all vhost injections from
Applications