Additional methods to manage buckets
Module that contains methods and functions to manage buckets.
Generated methods
DshApiClient methods that are generated from the openapi specification.
delete_bucket_access_configuration(id, name)delete_bucket_configuration(id)delete_bucket_watch_configuration(id)get_bucket(id) -> BucketStatusget_bucket_access(id, name) -> BucketAccessStatusget_bucket_access_actual(id, name) -> BucketAccessget_bucket_access_configuration(id, name) -> BucketAccessConfigurationget_bucket_access_ids(id) -> [id]get_bucket_access_status(id, name) -> AllocationStatusget_bucket_actual(id) -> Bucketget_bucket_configuration(id) -> Bucketget_bucket_fromthirdparty_ids() -> [id]get_bucket_ids() -> [id]get_bucket_status(id) -> AllocationStatusget_bucket_watch(id) -> BucketWatchStatusget_bucket_watch_actual(id) -> BucketWatchget_bucket_watch_configuration(id) -> BucketWatchget_bucket_watch_status(id) -> AllocationStatusget_bucketaccess_ids() -> [id]get_bucketwatch_ids() -> [id]get_thirdpartybucket(id) -> ThirdPartyBucketConcessionStatusget_thirdpartybucket_actual(id) -> ThirdPartyBucketConcessionget_thirdpartybucket_configuration(id) -> ThirdPartyBucketConcessionConfigurationget_thirdpartybucket_ids() -> [id]get_thirdpartybucket_status(id) -> AllocationStatuspost_thirdpartybucket(body)put_bucket_access_configuration(id, name, body)put_bucket_configuration(id, body)put_bucket_watch_configuration(id)
Derived methods
DshApiClient methods that add extra capabilities but do not directly call the
DSH resource management API. These derived methods depend on the API methods for this.
bucket_ids_with_dependants() -> [(bucket id, [dependant])]bucket_map() -> map(bucket id -> bucket)bucket_name(bucket id) -> bucket namebucket_with_dependants(bucket id) -> (bucket id, [dependant])]buckets() -> [(bucket id, bucket)]buckets_with_dependant_applications() -> [(bucket_id, bucket, [dependant application])]buckets_with_dependant_apps() -> [(bucket id, bucket, [dependant app])]buckets_with_dependants() -> [(bucket_id, [dependant])]
Enums
- Bucket
Injection - Describes an injection of a resource in an application
Constants
- OBJECT_
STORE_ ACCESS_ KEY_ ID - Secret name for object store access key id
- OBJECT_
STORE_ SECRET_ ACCESS_ KEY - Secret name for object store secret access key
Functions
- bucket_
injections_ from_ application - Get application environment variables referencing bucket
- bucket_
injections_ from_ applications - Get applications environment variables referencing bucket
- bucket_
resources_ from_ app - Get bucket resources from
AppCatalogApp - buckets_
from_ application - Get application environment variables referencing buckets
- buckets_
from_ applications - Get applications environment variables referencing buckets