pub struct DshJwtPayload {Show 22 fields
pub issuer: Option<String>,
pub subject: Option<String>,
pub audience: Option<String>,
pub expiration_time: Option<i64>,
pub not_before: Option<i64>,
pub issued_at: Option<i64>,
pub jwt_id: Option<String>,
pub authentication_time: Option<i64>,
pub authorized_party: Option<String>,
pub client_address: Option<String>,
pub client_host: Option<String>,
pub client_id: Option<String>,
pub dsh_permission_representations: Option<Vec<String>>,
pub email: Option<String>,
pub email_verified: Option<bool>,
pub family_name: Option<String>,
pub given_name: Option<String>,
pub name: Option<String>,
pub preferred_username: Option<String>,
pub scope: Option<String>,
pub session_id: Option<String>,
pub token_type: Option<String>,
}Fields
issuer: Option<String>Issuer claim (rfc7519 “iss”)
subject: Option<String>Subject claim (rfc7519 “sub”)
audience: Option<String>Audience claim (rfc7519 “aud”)
expiration_time: Option<i64>Expiration time claim (rfc7519 “exp”)
not_before: Option<i64>Not before claim (rfc7519 “nbf”)
issued_at: Option<i64>Issued at claim (rfc7519 “iat”)
jwt_id: Option<String>Jwt id claim (rfc7519 “jti”)
authentication_time: Option<i64>client_address: Option<String>client_host: Option<String>client_id: Option<String>dsh_permission_representations: Option<Vec<String>>Permission representations claim (dsh specific “dsh_perms”)
email: Option<String>email_verified: Option<bool>family_name: Option<String>given_name: Option<String>name: Option<String>preferred_username: Option<String>scope: Option<String>session_id: Option<String>token_type: Option<String>Implementations
Sourceimpl DshJwtPayload
impl DshJwtPayload
Sourcepub fn rfc7519_claims(&self) -> Vec<(&str, String)>
pub fn rfc7519_claims(&self) -> Vec<(&str, String)>
Returns a list of the available rfc7519 claims with their values
Returns
- List of tuples consisting of the claim name and value.
Sourcepub fn expires_in(&self) -> Option<i64>
pub fn expires_in(&self) -> Option<i64>
Returns expected time before token expires
Sourcepub fn permissions(&self) -> DshApiResult<Vec<DshPermission>>
pub fn permissions(&self) -> DshApiResult<Vec<DshPermission>>
Returns a list of permissions
Sourcepub fn authenticated_tenants(&self) -> DshApiResult<Vec<String>>
pub fn authenticated_tenants(&self) -> DshApiResult<Vec<String>>
Returns a list with the names of authenticated tenants