Enums, traits and structs used by the various find methods
Structs
- Dummy
Query Processor - Dummy query processor implementation
- Exact
Match Query Processor - Query processor implementation for exact matches
- Regex
Query Processor - Query processor implementation based on regular expressions
Enums
- Part
- Represents a part of a matched query.
Traits
- Query
Processor - Defines the methods in the query processor
Functions
- part_
to_ ansi_ formatted_ string - Generate string with ansi formatting from a
Part - parts_
to_ ansi_ formatted_ string - Generate string with ansi formatting from a slice of
Parts