Module types

Types generated from openapi file

Types used as operation parameters and responses.

Modules

defaults
Generation of default values for serde.
error
Error types.

Structs

ActualCertificate
information on a certificate which is provisioned on the platform
ActualCertificateAllOf
ActualCertificateAllOf
AllocationStatus
AllocationStatus
AllocationStatus1
AllocationStatus1
AppCatalogApp
AppCatalogApp
AppCatalogAppConfiguration
AppCatalogAppConfiguration
AppCatalogManifest
AppCatalogManifest
Application
Application
ApplicationSecret
a secret to be injected as an environment variable in the application
ApplicationVolumes
ApplicationVolumes
BaseLimitValue
BaseLimitValue
Bucket
Bucket
BucketAccess
BucketAccess
BucketAccessConfiguration
BucketAccessConfiguration
BucketAccessStatus
BucketAccessStatus
BucketStatus
BucketStatus
BucketWatch
BucketWatch
BucketWatchStatus
BucketWatchStatus
Certificate
information on a certificate which is wanted on the platform but may not yet be provisioned
CertificateStatus
CertificateStatus
ChildList
ChildList
ClientSecret
ClientSecret
DataCatalogAsset
DataCatalogAsset
DataCatalogAssetStatus
DataCatalogAssetStatus
Database
Database
DatabaseStatus
DatabaseStatus
DeleteAclgroupConfigurationByTenantByIdId
DeleteAclgroupConfigurationByTenantByIdId
Empty
Empty
FlinkCluster
FlinkCluster
FlinkClusterStatus
FlinkClusterStatus
FlinkJobManager
FlinkJobManager
FlinkTaskManager
FlinkTaskManager
GetAclgroupConfigurationByTenantByIdId
GetAclgroupConfigurationByTenantByIdId
HealthCheck
HealthCheck
KafkaAclGroup
information about a Kafka ACL group
KafkaAclGroupTopic
Kafka ACL group topic definition
KafkaProperties
Additional Kafka properties to be set on the topic. The properties are key-value pairs. The key is the property name and the value is the property value. The following properties are allowed:
KafkaProxy
KafkaProxy
KafkaProxyStatus
KafkaProxyStatus
KafkaProxyValidation
client certificate validations, only non empty values taken in account, no values means no validation
LimitValueCertificateCount
LimitValueCertificateCount
LimitValueCertificateCountAllOf
LimitValueCertificateCountAllOf
LimitValueConsumerRate
LimitValueConsumerRate
LimitValueConsumerRateAllOf
LimitValueConsumerRateAllOf
LimitValueCpu
LimitValueCpu
LimitValueCpuAllOf
LimitValueCpuAllOf
LimitValueKafkaAclGroupCount
LimitValueKafkaAclGroupCount
LimitValueKafkaAclGroupCountAllOf
LimitValueKafkaAclGroupCountAllOf
LimitValueMem
LimitValueMem
LimitValueMemAllOf
LimitValueMemAllOf
LimitValuePartitionCount
LimitValuePartitionCount
LimitValuePartitionCountAllOf
LimitValuePartitionCountAllOf
LimitValueProducerRate
LimitValueProducerRate
LimitValueProducerRateAllOf
LimitValueProducerRateAllOf
LimitValueRequestRate
LimitValueRequestRate
LimitValueRequestRateAllOf
LimitValueRequestRateAllOf
LimitValueSecretCount
LimitValueSecretCount
LimitValueSecretCountAllOf
LimitValueSecretCountAllOf
LimitValueTopicCount
LimitValueTopicCount
LimitValueTopicCountAllOf
LimitValueTopicCountAllOf
ManagedStream
ManagedStream
ManagedStreamId
The id of a managed stream consists of a managing prefix set specifically as a limit for each managing tenant, and name of the stream. The managing prefix and the name are separated by --- (three hyphens). For an stream called maerts for a tenant with an assigned managing prefix tnanet the full name would be tnanet---maerts. The public or internal type of the particular stream is set by using the corresponding /public/ or /internal/ methods in the managed streams API.
ManagedTenant
ManagedTenant
ManagedTenantServices
ManagedTenantServices
Metrics
metrics endpoint which will be scraped by the platform.
Notification
Notification
PathSpec
PathSpec
PortMapping
PortMapping
PublicManagedStream
A public stream. A stream that can be shared between different tenants, and is accessible over the MQTT protocol adapter.
PublicManagedStreamAllOf
PublicManagedStreamAllOf
PublicManagedStreamContract
The stream contract for a public stream.
PublicManagedStreamKafkaDefaultPartitioner
PublicManagedStreamKafkaDefaultPartitioner
PublicManagedStreamTopicLevelPartitioner
PublicManagedStreamTopicLevelPartitioner
PutAclgroupConfigurationByTenantByIdId
PutAclgroupConfigurationByTenantByIdId
Secret
Secret
Task
Task
TaskStatus
TaskStatus
ThirdPartyBucketConcession
ThirdPartyBucketConcession
ThirdPartyBucketConcessionConfiguration
ThirdPartyBucketConcessionConfiguration
ThirdPartyBucketConcessionRegistration
ThirdPartyBucketConcessionRegistration
ThirdPartyBucketConcessionStatus
ThirdPartyBucketConcessionStatus
Topic
Topic
TopicStatus
TopicStatus
Validations
Validations
Vhost
Vhost
Volume
Volume
VolumeStatus
VolumeStatus
Zone
available networks on this platform

Enums

AppCatalogAppResourcesValue
AppCatalogAppResourcesValue
BaseLimitValueName
BaseLimitValueName
DeleteDatacatalogAssetConfigurationByTenantByKindByNameKind
DeleteDatacatalogAssetConfigurationByTenantByKindByNameKind
GetDatacatalogAssetByTenantByKindByNameKind
GetDatacatalogAssetByTenantByKindByNameKind
GetDatacatalogAssetByTenantByKindKind
GetDatacatalogAssetByTenantByKindKind
GetDatacatalogAssetConfigurationByTenantByKindByNameKind
GetDatacatalogAssetConfigurationByTenantByKindByNameKind
GetTenantLimitByManagerByTenantByKindKind
GetTenantLimitByManagerByTenantByKindKind
HealthCheckProtocol
The protocol for for the health check (http or https)
KafkaAclGroupTopicKind
KafkaAclGroupTopicKind
KafkaProxyValidationSubjectType
EXACT for exact match, PATTERN for pattern match
KafkaProxyZone
Available networks on this platform
LimitValue
LimitValue
LimitValueCertificateCountName
LimitValueCertificateCountName
LimitValueConsumerRateName
LimitValueConsumerRateName
LimitValueCpuName
LimitValueCpuName
LimitValueKafkaAclGroupCountName
LimitValueKafkaAclGroupCountName
LimitValueMemName
LimitValueMemName
LimitValuePartitionCountName
LimitValuePartitionCountName
LimitValueProducerRateName
LimitValueProducerRateName
LimitValueRequestRateName
LimitValueRequestRateName
LimitValueSecretCountName
LimitValueSecretCountName
LimitValueTopicCountName
LimitValueTopicCountName
ManagedTenantServicesName
ManagedTenantServicesName
PortMappingTls
The default is ‘auto’, indicating that the port will only accept secured connections. Put this to ‘none’ if you do not want the service to have a secure endpoint.
PublicManagedStreamContractPartitioner
The partitioner used to partition messages across different kafka partitions.
PublicManagedStreamKafkaDefaultPartitionerKind
PublicManagedStreamKafkaDefaultPartitionerKind
PublicManagedStreamTopicLevelPartitionerKind
PublicManagedStreamTopicLevelPartitionerKind
PutDatacatalogAssetConfigurationByTenantByKindByNameKind
PutDatacatalogAssetConfigurationByTenantByKindByNameKind
PutTenantLimitByManagerByTenantByKindKind
PutTenantLimitByManagerByTenantByKindKind
TaskState
The state the task is in
ZoneNetwork
ZoneNetwork