Types generated from openapi file
Types used as operation parameters and responses.
Modules
Structs
- Actual
Certificate - information on a certificate which is provisioned on the platform
- Actual
Certificate AllOf - ActualCertificateAllOf
- Allocation
Status - AllocationStatus
- Allocation
Status1 - AllocationStatus1
- AppCatalog
App - AppCatalogApp
- AppCatalog
AppConfiguration - AppCatalogAppConfiguration
- AppCatalog
Manifest - AppCatalogManifest
- Application
- Application
- Application
Secret - a secret to be injected as an environment variable in the application
- Application
Volumes - ApplicationVolumes
- Base
Limit Value - BaseLimitValue
- Bucket
- Bucket
- Bucket
Access - BucketAccess
- Bucket
Access Configuration - BucketAccessConfiguration
- Bucket
Access Status - BucketAccessStatus
- Bucket
Status - BucketStatus
- Bucket
Watch - BucketWatch
- Bucket
Watch Status - BucketWatchStatus
- Certificate
- information on a certificate which is wanted on the platform but may not yet be provisioned
- Certificate
Status - CertificateStatus
- Child
List - ChildList
- Client
Secret - ClientSecret
- Data
Catalog Asset - DataCatalogAsset
- Data
Catalog Asset Status - DataCatalogAssetStatus
- Database
- Database
- Database
Status - DatabaseStatus
- Delete
Aclgroup Configuration ByTenant ById Id - DeleteAclgroupConfigurationByTenantByIdId
- Empty
- Empty
- Flink
Cluster - FlinkCluster
- Flink
Cluster Status - FlinkClusterStatus
- Flink
JobManager - FlinkJobManager
- Flink
Task Manager - FlinkTaskManager
- GetAclgroup
Configuration ByTenant ById Id - GetAclgroupConfigurationByTenantByIdId
- Health
Check - HealthCheck
- Kafka
AclGroup - information about a Kafka ACL group
- Kafka
AclGroup Topic - Kafka ACL group topic definition
- Kafka
Properties - Additional Kafka properties to be set on the topic. The properties are key-value pairs. The key is the property name and the value is the property value. The following properties are allowed:
- Kafka
Proxy - KafkaProxy
- Kafka
Proxy Status - KafkaProxyStatus
- Kafka
Proxy Validation - client certificate validations, only non empty values taken in account, no values means no validation
- Limit
Value Certificate Count - LimitValueCertificateCount
- Limit
Value Certificate Count AllOf - LimitValueCertificateCountAllOf
- Limit
Value Consumer Rate - LimitValueConsumerRate
- Limit
Value Consumer Rate AllOf - LimitValueConsumerRateAllOf
- Limit
Value Cpu - LimitValueCpu
- Limit
Value CpuAll Of - LimitValueCpuAllOf
- Limit
Value Kafka AclGroup Count - LimitValueKafkaAclGroupCount
- Limit
Value Kafka AclGroup Count AllOf - LimitValueKafkaAclGroupCountAllOf
- Limit
Value Mem - LimitValueMem
- Limit
Value MemAll Of - LimitValueMemAllOf
- Limit
Value Partition Count - LimitValuePartitionCount
- Limit
Value Partition Count AllOf - LimitValuePartitionCountAllOf
- Limit
Value Producer Rate - LimitValueProducerRate
- Limit
Value Producer Rate AllOf - LimitValueProducerRateAllOf
- Limit
Value Request Rate - LimitValueRequestRate
- Limit
Value Request Rate AllOf - LimitValueRequestRateAllOf
- Limit
Value Secret Count - LimitValueSecretCount
- Limit
Value Secret Count AllOf - LimitValueSecretCountAllOf
- Limit
Value Topic Count - LimitValueTopicCount
- Limit
Value Topic Count AllOf - LimitValueTopicCountAllOf
- Managed
Stream - ManagedStream
- Managed
Stream Id - The id of a managed stream consists of a managing prefix set specifically as a limit for each managing tenant, and name of the stream. The managing prefix and the name are separated by
---(three hyphens). For an stream calledmaertsfor a tenant with an assigned managing prefixtnanetthe full name would betnanet---maerts. The public or internal type of the particular stream is set by using the corresponding/public/or/internal/methods in the managed streams API. - Managed
Tenant - ManagedTenant
- Managed
Tenant Services - ManagedTenantServices
- Metrics
- metrics endpoint which will be scraped by the platform.
- Notification
- Notification
- Path
Spec - PathSpec
- Port
Mapping - PortMapping
- Public
Managed Stream - A public stream. A stream that can be shared between different tenants, and is accessible over the MQTT protocol adapter.
- Public
Managed Stream AllOf - PublicManagedStreamAllOf
- Public
Managed Stream Contract - The stream contract for a public stream.
- Public
Managed Stream Kafka Default Partitioner - PublicManagedStreamKafkaDefaultPartitioner
- Public
Managed Stream Topic Level Partitioner - PublicManagedStreamTopicLevelPartitioner
- PutAclgroup
Configuration ByTenant ById Id - PutAclgroupConfigurationByTenantByIdId
- Secret
- Secret
- Task
- Task
- Task
Status - TaskStatus
- Third
Party Bucket Concession - ThirdPartyBucketConcession
- Third
Party Bucket Concession Configuration - ThirdPartyBucketConcessionConfiguration
- Third
Party Bucket Concession Registration - ThirdPartyBucketConcessionRegistration
- Third
Party Bucket Concession Status - ThirdPartyBucketConcessionStatus
- Topic
- Topic
- Topic
Status - TopicStatus
- Validations
- Validations
- Vhost
- Vhost
- Volume
- Volume
- Volume
Status - VolumeStatus
- Zone
- available networks on this platform
Enums
- AppCatalog
AppResources Value - AppCatalogAppResourcesValue
- Base
Limit Value Name - BaseLimitValueName
- Delete
Datacatalog Asset Configuration ByTenant ByKind ByName Kind - DeleteDatacatalogAssetConfigurationByTenantByKindByNameKind
- GetDatacatalog
Asset ByTenant ByKind ByName Kind - GetDatacatalogAssetByTenantByKindByNameKind
- GetDatacatalog
Asset ByTenant ByKind Kind - GetDatacatalogAssetByTenantByKindKind
- GetDatacatalog
Asset Configuration ByTenant ByKind ByName Kind - GetDatacatalogAssetConfigurationByTenantByKindByNameKind
- GetTenant
Limit ByManager ByTenant ByKind Kind - GetTenantLimitByManagerByTenantByKindKind
- Health
Check Protocol - The protocol for for the health check (http or https)
- Kafka
AclGroup Topic Kind - KafkaAclGroupTopicKind
- Kafka
Proxy Validation Subject Type - EXACT for exact match, PATTERN for pattern match
- Kafka
Proxy Zone - Available networks on this platform
- Limit
Value - LimitValue
- Limit
Value Certificate Count Name - LimitValueCertificateCountName
- Limit
Value Consumer Rate Name - LimitValueConsumerRateName
- Limit
Value CpuName - LimitValueCpuName
- Limit
Value Kafka AclGroup Count Name - LimitValueKafkaAclGroupCountName
- Limit
Value MemName - LimitValueMemName
- Limit
Value Partition Count Name - LimitValuePartitionCountName
- Limit
Value Producer Rate Name - LimitValueProducerRateName
- Limit
Value Request Rate Name - LimitValueRequestRateName
- Limit
Value Secret Count Name - LimitValueSecretCountName
- Limit
Value Topic Count Name - LimitValueTopicCountName
- Managed
Tenant Services Name - ManagedTenantServicesName
- Port
Mapping Tls - The default is ‘auto’, indicating that the port will only accept secured connections. Put this to ‘none’ if you do not want the service to have a secure endpoint.
- Public
Managed Stream Contract Partitioner - The partitioner used to partition messages across different kafka partitions.
- Public
Managed Stream Kafka Default Partitioner Kind - PublicManagedStreamKafkaDefaultPartitionerKind
- Public
Managed Stream Topic Level Partitioner Kind - PublicManagedStreamTopicLevelPartitionerKind
- PutDatacatalog
Asset Configuration ByTenant ByKind ByName Kind - PutDatacatalogAssetConfigurationByTenantByKindByNameKind
- PutTenant
Limit ByManager ByTenant ByKind Kind - PutTenantLimitByManagerByTenantByKindKind
- Task
State - The state the task is in
- Zone
Network - ZoneNetwork