pub struct AllocationStatus {
pub derived_from: Option<String>,
pub notifications: Vec<Notification>,
pub provisioned: bool,
}Expand description
AllocationStatus
JSON schema
{
"type": "object",
"required": [
"notifications",
"provisioned"
],
"properties": {
"derivedFrom": {
"description": "pointer to the parent allocation or limit that caused this allocation to be implicitly created\n",
"type": "string"
},
"notifications": {
"type": "array",
"items": {
"$ref": "#/components/schemas/Notification"
}
},
"provisioned": {
"description": "indicates whether configuration and actual state match",
"type": "boolean"
}
},
"example": {
"derivedFrom": "derivedFrom",
"notifications": [
{
"args": {
"key": "args"
},
"message": "message",
"remove": true
},
{
"args": {
"key": "args"
},
"message": "message",
"remove": true
}
],
"provisioned": true
}
}Fields
derived_from: Option<String>pointer to the parent allocation or limit that caused this allocation to be implicitly created
notifications: Vec<Notification>provisioned: boolindicates whether configuration and actual state match
Implementations
Sourceimpl AllocationStatus
impl AllocationStatus
pub fn builder() -> AllocationStatus
Sourceimpl AllocationStatus
impl AllocationStatus
Sourcepub fn new<T>(derived_from: T, provisioned: bool) -> Self
pub fn new<T>(derived_from: T, provisioned: bool) -> Self
Create a new AllocationStatus
Create a new AllocationStatus from the provided parameters.
The other fields of the AllocationStatus instance will be set to their default values.
Parameters
derived_from- name of the service that the resource for this allocation status was derived fromprovisioned- whether the service was provisioned
Returns
The created AllocationStatus.
Example
let allocation_status = AllocationStatus::new("my-service", true);
assert_eq!(allocation_status.derived_from.unwrap(), "my-service".to_string());
assert_eq!(allocation_status.provisioned, true);
assert!(allocation_status.notifications.is_empty());Trait Implementations
Sourceimpl Clone for AllocationStatus
impl Clone for AllocationStatus
Sourcefn clone(&self) -> AllocationStatus
fn clone(&self) -> AllocationStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AllocationStatus
impl Debug for AllocationStatus
Sourceimpl Default for AllocationStatus
impl Default for AllocationStatus
Sourceimpl<'de> Deserialize<'de> for AllocationStatus
impl<'de> Deserialize<'de> for AllocationStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for AllocationStatus
impl Display for AllocationStatus
Sourceimpl From<AllocationStatus> for AllocationStatus
impl From<AllocationStatus> for AllocationStatus
Sourcefn from(value: AllocationStatus) -> Self
fn from(value: AllocationStatus) -> Self
Converts to this type from the input type.
Sourceimpl From<AllocationStatus> for AllocationStatus1
impl From<AllocationStatus> for AllocationStatus1
Sourcefn from(value: AllocationStatus) -> Self
fn from(value: AllocationStatus) -> Self
Converts to this type from the input type.
Sourceimpl From<AllocationStatus1> for AllocationStatus
impl From<AllocationStatus1> for AllocationStatus
Sourcefn from(value: AllocationStatus1) -> Self
fn from(value: AllocationStatus1) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for AllocationStatus
impl PartialEq for AllocationStatus
Sourceimpl Serialize for AllocationStatus
impl Serialize for AllocationStatus
Sourceimpl TryFrom<AllocationStatus> for AllocationStatus
impl TryFrom<AllocationStatus> for AllocationStatus
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.
Sourcefn try_from(value: AllocationStatus) -> Result<Self, ConversionError>
fn try_from(value: AllocationStatus) -> Result<Self, ConversionError>
Performs the conversion.
impl StructuralPartialEq for AllocationStatus