pub struct Task {
pub healthy: Option<bool>,
pub host: Ipv4Addr,
pub last_update: Option<i64>,
pub logs: Option<String>,
pub staged_at: DateTime<Utc>,
pub started_at: DateTime<Utc>,
pub state: TaskState,
pub stopped_at: Option<DateTime<Utc>>,
}Expand description
Task
JSON schema
{
"examples": [
{
"healthy": true,
"host": "10.0.2.36",
"lastUpdate": 1638980430,
"stagedAt": "2017-12-07T10:53:46.643Z",
"startedAt": "2017-12-07T10:55:41.765Z",
"state": "RUNNING",
"stoppedAt": "2017-12-07T10:58:41.765Z"
}
],
"type": "object",
"required": [
"host",
"stagedAt",
"startedAt",
"state"
],
"properties": {
"healthy": {
"description": "false or true depending on health checks (empty if no health checks)\n",
"type": "boolean"
},
"host": {
"description": "The IP address of the host the task is running on (not the IP address of the task itself)\n",
"type": "string",
"format": "ipv4"
},
"lastUpdate": {
"description": "Timestamp of the last time the task was updated",
"type": "integer",
"format": "int64"
},
"logs": {
"description": "Optional link to the latest log dump for this task",
"type": "string",
"format": "url"
},
"stagedAt": {
"description": "Staging time of the task",
"type": "string",
"format": "date-time"
},
"startedAt": {
"description": "Start time of the task",
"type": "string",
"format": "date-time"
},
"state": {
"description": "The state the task is in",
"type": "string",
"enum": [
"DROPPED",
"ERROR",
"FAILED",
"FINISHED",
"GONE",
"GONE_BY_OPERATOR",
"KILLED",
"KILLING",
"LOST",
"RUNNING",
"STAGING",
"STARTING",
"UNKNOWN",
"UNREACHABLE"
]
},
"stoppedAt": {
"description": "Stopped time of the task",
"type": "string",
"format": "date-time"
}
}
}Fields
healthy: Option<bool>false or true depending on health checks (empty if no health checks)
host: Ipv4AddrThe IP address of the host the task is running on (not the IP address of the task itself)
last_update: Option<i64>Timestamp of the last time the task was updated
logs: Option<String>Optional link to the latest log dump for this task
staged_at: DateTime<Utc>Staging time of the task
started_at: DateTime<Utc>Start time of the task
state: TaskStateThe state the task is in
stopped_at: Option<DateTime<Utc>>Stopped time of the task